Homing

Enum Homing 

pub enum Homing {
    Scoop,
    Bar,
    Bump,
}
The type of homing used on a homing key

Variants



Scoop

A scooped homing key, also known as a dished homing key



Bar

A key with a homing bar, sometimes called a line



Bump

A key with a homing bump, also known as a nub, dot, or nipple